@@ -4,9 +4,12 @@ import (
 	"fmt"
 	"time"
 
+	"gitlab.com/gitlab-org/cli/internal/mcpannotations"
+
 	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/internal/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/commands/ci/ciutils"
+	"gitlab.com/gitlab-org/cli/internal/commands/mr/mrutils"
 	"gitlab.com/gitlab-org/cli/internal/dbg"
 	"gitlab.com/gitlab-org/cli/internal/utils"
 
@@ -22,19 +25,22 @@ func NewCmdStatus(f cmdutils.Factory) *cobra.Command {
 		Short:   `View a running CI/CD pipeline on current or other branch specified.`,
 		Aliases: []string{"stats"},
 		Example: heredoc.Doc(`
-			$ glab ci status --live
+		       $ glab ci status --live
 
-			# A more compact view
-			$ glab ci status --compact
+		       # A more compact view
+		       $ glab ci status --compact
 
-			# Get the pipeline for the main branch
-			$ glab ci status --branch=main
+		       # Get the pipeline for the main branch
+		       $ glab ci status --branch=main
 
-			# Get the pipeline for the current branch
-			$ glab ci status
-		`),
+		       # Get the pipeline for the current branch
+		       $ glab ci status
+	       `),
 		Long: ``,
 		Args: cobra.ExactArgs(0),
+		Annotations: map[string]string{
+			mcpannotations.Safe: "true",
+		},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
 			c := f.IO().Color()
@@ -54,14 +60,17 @@ func NewCmdStatus(f cmdutils.Factory) *cobra.Command {
 			repoName := repo.FullName()
 			dbg.Debug("Repository:", repoName)
 
+			// Get the correct branch name using the utility function
 			branch = ciutils.GetBranch(branch, func() (string, error) {
 				return f.Branch()
 			}, repo, client)
 			dbg.Debug("Using branch:", branch)
-			runningPipeline, _, err := client.Pipelines.GetLatestPipeline(repoName, &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr(branch)})
+
+			// Use fallback logic for robust pipeline lookup
+			runningPipeline, err := getPipelineWithFallback(client, f, repoName, branch)
 			if err != nil {
 				redCheck := c.Red("✘")
-				fmt.Fprintf(f.IO().StdOut, "%s No pipelines running or available on branch: %s\n", redCheck, branch)
+				fmt.Fprintf(f.IO().StdOut, "%s %v\n", redCheck, err)
 				return err
 			}
 
@@ -101,7 +110,6 @@ func NewCmdStatus(f cmdutils.Factory) *cobra.Command {
 					default:
 						status = c.Gray(s)
 					}
-					// fmt.Println(job.Tag)
 					if compact {
 						fmt.Fprintf(writer, "(%s) • %s [%s]\n", status, job.Name, job.Stage)
 					} else {
@@ -116,10 +124,16 @@ func NewCmdStatus(f cmdutils.Factory) *cobra.Command {
 				fmt.Fprintf(writer.Newline(), "Pipeline state: %s\n\n", runningPipeline.Status)
 
 				if (runningPipeline.Status == "pending" || runningPipeline.Status == "running") && live {
-					runningPipeline, _, err = client.Pipelines.GetLatestPipeline(repoName, &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr(branch)})
+					// Use fallback logic for live updates
+					updatedPipeline, err := getPipelineWithFallback(client, f, repoName, branch)
 					if err != nil {
-						return err
+						// Final fallback: refresh current pipeline by ID
+						updatedPipeline, _, err = client.Pipelines.GetPipeline(repoName, runningPipeline.ID)
+						if err != nil {
+							return err
+						}
 					}
+					runningPipeline = updatedPipeline
 				} else if f.IO().IsInputTTY() && f.IO().PromptEnabled() {
 					prompt := &survey.Select{
 						Message: "Choose an action:",
@@ -142,17 +156,23 @@ func NewCmdStatus(f cmdutils.Factory) *cobra.Command {
 						if err != nil {
 							return err
 						}
-						runningPipeline, _, err = client.Pipelines.GetLatestPipeline(repoName, &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr(branch)})
+						updatedPipeline, err := getPipelineWithFallback(client, f, repoName, branch)
 						if err != nil {
-							return err
+							// Fallback: refresh by pipeline ID if MR lookup fails
+							updatedPipeline, _, err = client.Pipelines.GetPipeline(repoName, runningPipeline.ID)
+							if err != nil {
+								return err
+							}
 						}
+						runningPipeline = updatedPipeline
 					default:
-						break
+						goto exitLoop
 					}
 				} else {
 					break
 				}
 			}
+		exitLoop:
 			if runningPipeline.Status == "failed" {
 				return cmdutils.SilentError
 			}
@@ -166,3 +186,29 @@ func NewCmdStatus(f cmdutils.Factory) *cobra.Command {
 
 	return pipelineStatusCmd
 }
+
+func getPipelineWithFallback(client *gitlab.Client, f cmdutils.Factory, repoName, branch string) (*gitlab.Pipeline, error) {
+	// First try: Get pipeline by branch name
+	pipeline, _, err := client.Pipelines.GetLatestPipeline(repoName, &gitlab.GetLatestPipelineOptions{Ref: gitlab.Ptr(branch)})
+	if err == nil {
+		return pipeline, nil
+	}
+
+	// Fallback: Look for MR pipeline
+	mr, _, mrErr := mrutils.MRFromArgs(f, []string{}, "any")
+	if mr == nil || mrErr != nil {
+		return nil, fmt.Errorf("no pipeline found for branch %s and no associated merge request found. Branch may not have an open MR", branch)
+	}
+
+	if mr.HeadPipeline == nil {
+		return nil, fmt.Errorf("no pipeline found. It might not exist yet. If this problem continues, check your pipeline configuration.")
+	}
+
+	// Get the full pipeline details using the MR's head pipeline ID
+	pipeline, _, pipelineErr := client.Pipelines.GetPipeline(repoName, mr.HeadPipeline.ID)
+	if pipelineErr != nil {
+		return nil, pipelineErr
+	}
+
+	return pipeline, nil
+}
