@@ -42,6 +42,7 @@ type options struct {
 
 	refName       string
 	openInBrowser bool
+	pipelineID    int
 }
 
 type ViewJobKind int64
@@ -154,6 +155,8 @@ func NewCmdView(f cmdutils.Factory) *cobra.Command {
 	pipelineCIView.Flags().
 		StringVarP(&opts.refName, "branch", "b", "", "Check pipeline status for a branch or tag. Defaults to the current branch.")
 	pipelineCIView.Flags().BoolVarP(&opts.openInBrowser, "web", "w", false, "Open pipeline in a browser. Uses default browser, or browser specified in BROWSER variable.")
+	pipelineCIView.Flags().IntVarP(&opts.pipelineID, "pipelineid", "p", 0, "Check pipeline status for a specific pipeline ID.")
+	pipelineCIView.MarkFlagsMutuallyExclusive("branch", "pipelineid")
 
 	return pipelineCIView
 }
@@ -186,33 +189,55 @@ func (o *options) run() error {
 	}
 
 	projectID := repo.FullName()
+	var pipelineID int
+	var webURL string
+	var pipelineCreatedAt time.Time
+	var commit *gitlab.Commit
+	var commitSHA string
 
-	commit, _, err := client.Commits.GetCommit(projectID, o.refName, nil)
-	if err != nil {
-		return err
+	if o.pipelineID != 0 {
+		pipeline, _, err := client.Pipelines.GetPipeline(projectID, o.pipelineID)
+		if err != nil {
+			return err
+		}
+
+		pipelineID = pipeline.ID
+		webURL = pipeline.WebURL
+		pipelineCreatedAt = *pipeline.CreatedAt
+		commitSHA = pipeline.SHA
+		commit, _, err = client.Commits.GetCommit(projectID, commitSHA, nil)
+		if err != nil {
+			return err
+		}
+	} else {
+		commit, _, err = client.Commits.GetCommit(projectID, o.refName, nil)
+		if err != nil {
+			return err
+		}
+
+		if commit.LastPipeline == nil {
+			return fmt.Errorf("Can't find pipeline for commit: %s", commit.ID)
+		}
+
+		pipelineID = commit.LastPipeline.ID
+		webURL = commit.LastPipeline.WebURL
+		pipelineCreatedAt = *commit.LastPipeline.CreatedAt
+		commitSHA = commit.ID
 	}
 
-	commitSHA := commit.ID
-	if commit.LastPipeline == nil {
-		return fmt.Errorf("Can't find pipeline for commit: %s", commitSHA)
-	}
-
-	cfg := o.config()
-
 	if o.openInBrowser { // open in browser if --web flag is specified
-		webURL := commit.LastPipeline.WebURL
-
 		if o.io.IsOutputTTY() {
 			fmt.Fprintf(o.io.StdErr, "Opening %s in your browser.\n", utils.DisplayURL(webURL))
 		}
 
+		cfg := o.config()
 		browser, _ := cfg.Get(repo.RepoHost(), "browser")
 		return utils.OpenInBrowser(webURL, browser)
 	}
 
-	p, _, err := client.Pipelines.GetPipeline(projectID, commit.LastPipeline.ID)
+	p, _, err := client.Pipelines.GetPipeline(projectID, pipelineID)
 	if err != nil {
-		return fmt.Errorf("Can't get pipeline #%d info: %s", commit.LastPipeline.ID, err)
+		return fmt.Errorf("Can't get pipeline #%d info: %s", pipelineID, err)
 	}
 	pipelineUser := p.User
 
@@ -223,7 +248,7 @@ func (o *options) run() error {
 		SetBackgroundColor(tcell.ColorDefault).
 		SetBorderPadding(1, 1, 2, 2).
 		SetBorder(true).
-		SetTitle(fmt.Sprintf(" Pipeline #%d triggered %s by %s ", commit.LastPipeline.ID, utils.TimeToPrettyTimeAgo(*commit.LastPipeline.CreatedAt), pipelineUser.Name))
+		SetTitle(fmt.Sprintf(" Pipeline #%d triggered %s by %s ", pipelineID, utils.TimeToPrettyTimeAgo(pipelineCreatedAt), pipelineUser.Name))
 
 	boxes = make(map[string]*tview.TextView)
 	jobsCh := make(chan []*ViewJob)
@@ -441,6 +466,55 @@ var (
 	boxes                     map[string]*tview.TextView
 )
 
+// bracketEscaper wraps a writer and escapes square brackets for tview, but preserves ANSI escape sequences.
+// This is necessary because tview interprets square brackets as color tag markers.
+// For example, [MASKED] would be treated as a color tag and stripped from display.
+// By escaping closing brackets to [], we prevent tview from parsing literal brackets as tags.
+type bracketEscaper struct {
+	io.Writer
+}
+
+func (b *bracketEscaper) Write(p []byte) (int, error) {
+	// Build escaped output, preserving ANSI escape sequences
+	// In tview's escaping convention, only closing ] needs to be escaped to []
+	var result strings.Builder
+	i := 0
+	for i < len(p) {
+		// Check if this is the start of an ANSI escape sequence: ESC [
+		if i < len(p)-1 && p[i] == '\x1b' && p[i+1] == '[' {
+			// Find the end of the ANSI sequence (ends with a letter)
+			result.WriteByte(p[i])   // ESC
+			result.WriteByte(p[i+1]) // [
+			i += 2
+			// Copy the rest of the ANSI sequence
+			for i < len(p) && !((p[i] >= 'A' && p[i] <= 'Z') || (p[i] >= 'a' && p[i] <= 'z')) {
+				result.WriteByte(p[i])
+				i++
+			}
+			if i < len(p) {
+				result.WriteByte(p[i]) // Final letter
+				i++
+			}
+		} else if p[i] == ']' {
+			// Literal closing bracket - escape it for tview by replacing with []
+			result.WriteString("[]")
+			i++
+		} else {
+			result.WriteByte(p[i])
+			i++
+		}
+	}
+
+	// Write the escaped data to the underlying writer
+	_, err := b.Writer.Write([]byte(result.String()))
+	if err != nil {
+		return 0, err
+	}
+	// Return the number of bytes consumed from input (per io.Writer contract)
+	// We successfully processed all input bytes even though output may be longer
+	return len(p), nil
+}
+
 func curPipeline(commit *gitlab.Commit) gitlab.PipelineInfo {
 	if len(pipelines) == 0 {
 		return *commit.LastPipeline
@@ -580,10 +654,26 @@ func jobsView(
 				SetBorder(true)
 
 			go func() {
+				// Chain: bracketEscaper -> vtclean -> ANSIWriter -> TextView
+				//
+				// The bracketEscaper must come FIRST in the chain to escape literal square
+				// brackets (like [MASKED]) before they reach tview. This prevents tview from
+				// interpreting them as color tags and removing them.
+				//
+				// Flow:
+				// 1. Raw trace with ANSI codes and [MASKED] text
+				// 2. bracketEscaper: Escapes ] to [] while preserving ANSI codes
+				// 3. vtclean: Cleans terminal control sequences, preserves ANSI colors
+				// 4. ANSIWriter: Converts ANSI codes to tview color tags
+				// 5. TextView: Displays with colors and escaped brackets
+				ansiWriter := tview.ANSIWriter(tv)
+				vtcleanWriter := vtclean.NewWriter(ansiWriter, true)
+				bracketWriter := &bracketEscaper{Writer: vtcleanWriter}
+
 				err := ciutils.RunTraceSha(
 					context.Background(),
 					apiClient,
-					vtclean.NewWriter(tview.ANSIWriter(tv), true),
+					bracketWriter,
 					projectID,
 					commitSHA,
 					curJob.Name,
