@@ -1174,6 +1174,62 @@ func runCommand(t *testing.T, rt http.RoundTripper, cli string) (*test.CmdOut, e
 	return cmdOut, err, restoreCmd
 }
 
+func Test_bracketEscaper(t *testing.T) {
+	t.Parallel()
+
+	tests := []struct {
+		desc     string
+		input    string
+		expected string
+	}{
+		{
+			desc:     "no brackets",
+			input:    "simple text",
+			expected: "simple text",
+		},
+		{
+			desc:     "literal brackets [MASKED]",
+			input:    "value is [MASKED]",
+			expected: "value is [MASKED[]",
+		},
+		{
+			desc:     "ANSI escape sequence preserved",
+			input:    "\x1b[32;1mgreen text\x1b[0m",
+			expected: "\x1b[32;1mgreen text\x1b[0m",
+		},
+		{
+			desc:     "ANSI with literal brackets",
+			input:    "\x1b[32;1m$ echo \"test\"\x1b[0m\nvalue is [MASKED]\n",
+			expected: "\x1b[32;1m$ echo \"test\"\x1b[0m\nvalue is [MASKED[]\n",
+		},
+		{
+			desc:     "multiple literal brackets",
+			input:    "[MASKED] and [HIDDEN]",
+			expected: "[MASKED[] and [HIDDEN[]",
+		},
+		{
+			desc:     "complex trace with section markers",
+			input:    "Compile complete.\n\x1b[32;1m$ echo \"MASKED variables's value is ${TEST_MASKED}\"\x1b[0m\nMASKED variables's value is [MASKED]\n",
+			expected: "Compile complete.\n\x1b[32;1m$ echo \"MASKED variables's value is ${TEST_MASKED}\"\x1b[0m\nMASKED variables's value is [MASKED[]\n",
+		},
+	}
+
+	for _, test := range tests {
+		t.Run(test.desc, func(t *testing.T) {
+			t.Parallel()
+
+			var output strings.Builder
+			escaper := &bracketEscaper{Writer: &output}
+
+			n, err := escaper.Write([]byte(test.input))
+
+			assert.NoError(t, err)
+			assert.Equal(t, len(test.input), n, "should return number of input bytes consumed")
+			assert.Equal(t, test.expected, output.String())
+		})
+	}
+}
+
 func TestCIView(t *testing.T) {
 	type httpMock struct {
 		method string
@@ -1204,7 +1260,8 @@ func TestCIView(t *testing.T) {
 							"ref": "main",
 							"sha": "2dc6aa325a317eda67812f05600bdf0fcdc70ab0",
 							"status": "created",
-							"web_url": "https://gitlab.com/OWNER/REPO/-/pipelines/225"
+							"web_url": "https://gitlab.com/OWNER/REPO/-/pipelines/225",
+							"created_at": "2025-10-28T16:52:39.000+01:00"
 						},
 						"status": "running"
 					}`,
@@ -1212,6 +1269,42 @@ func TestCIView(t *testing.T) {
 			},
 			expectedOutput: "Opening gitlab.com/OWNER/REPO/-/pipelines/225 in your browser.\n",
 		},
+		{
+			name: "view ci pipeline on web for a given pipeline id",
+			cli:  "--web --pipelineid 5",
+			httpMocks: []httpMock{
+				{
+					http.MethodGet,
+					"https://gitlab.com/api/v4/projects/OWNER%2FREPO/pipelines/5",
+					http.StatusOK,
+					`
+					{
+						"id": 5,
+						"web_url": "https://gitlab.com/OWNER/REPO/-/pipelines/5",
+						"created_at": "2025-10-28T16:52:39.000+01:00",
+						"sha": "2dc6aa325a317eda67812f05600bdf0fcdc70ab0"
+					}`,
+				},
+				{
+					http.MethodGet,
+					"https://gitlab.com/api/v4/projects/OWNER%2FREPO/repository/commits/2dc6aa325a317eda67812f05600bdf0fcdc70ab0",
+					http.StatusOK,
+					`{
+						"id": "6104942438c14ec7bd21c6cd5bd995272b3faff6",
+						"last_pipeline": {
+							"id": 5,
+							"ref": "main",
+							"sha": "2dc6aa325a317eda67812f05600bdf0fcdc70ab0",
+							"status": "created",
+							"web_url": "https://gitlab.com/OWNER/REPO/-/pipelines/225",
+							"created_at": "2025-10-28T16:52:39.000+01:00"
+						},
+						"status": "running"
+					}`,
+				},
+			},
+			expectedOutput: "Opening gitlab.com/OWNER/REPO/-/pipelines/5 in your browser.\n",
+		},
 	}
 
 	for _, tc := range tests {
@@ -1231,7 +1324,6 @@ func TestCIView(t *testing.T) {
 			if assert.NoErrorf(t, err, "error running command `ci view %s`: %v", tc.cli, err) {
 				assert.Empty(t, output.String())
 				assert.Equal(t, tc.expectedOutput, output.Stderr())
-
 			}
 		})
 	}
