@@ -4,13 +4,15 @@ import (
 	"errors"
 	"fmt"
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/survivorbat/huhtest"
 	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/internal/api"
 	"gitlab.com/gitlab-org/cli/internal/git"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
-	"gitlab.com/gitlab-org/cli/internal/prompt"
+	"gitlab.com/gitlab-org/cli/internal/iostreams"
 	"gitlab.com/gitlab-org/cli/internal/testing/cmdtest"
 )
 
@@ -366,7 +368,7 @@ func Test_getMRForBranchFails(t *testing.T) {
 			return nil, errors.New("API call failed")
 		}
 
-		got, err := GetMRForBranch(&gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
+		got, err := GetMRForBranch(nil, &gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `failed to get open merge request for "foo": API call failed`)
 	})
@@ -376,7 +378,7 @@ func Test_getMRForBranchFails(t *testing.T) {
 			return []*gitlab.BasicMergeRequest{}, nil
 		}
 
-		got, err := GetMRForBranch(&gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
+		got, err := GetMRForBranch(nil, &gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `no open merge request available for "foo"`)
 	})
@@ -399,7 +401,7 @@ func Test_getMRForBranchFails(t *testing.T) {
 			}, nil
 		}
 
-		got, err := GetMRForBranch(&gitlab.Client{}, MrOptions{baseRepo, "zemzale:foo", "opened", true})
+		got, err := GetMRForBranch(nil, &gitlab.Client{}, MrOptions{baseRepo, "zemzale:foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `no open merge request available for "foo" owned by @zemzale`)
 	})
@@ -466,7 +468,7 @@ func Test_getMRForBranch(t *testing.T) {
 				return tC.mrs, nil
 			}
 
-			got, err := GetMRForBranch(&gitlab.Client{}, MrOptions{baseRepo, tC.input, "opened", true})
+			got, err := GetMRForBranch(nil, &gitlab.Client{}, MrOptions{baseRepo, tC.input, "opened", true})
 			assert.NoError(t, err)
 
 			assert.Equal(t, tC.expect.IID, got.IID)
@@ -495,39 +497,18 @@ func Test_getMRForBranchPrompt(t *testing.T) {
 		}, nil
 	}
 
-	t.Run("success", func(t *testing.T) {
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
+	stdin, stdout, cancel := huhtest.NewResponder().
+		AddSelect(multipleMRSelectQuestion, 0).
+		Start(t, 1*time.Hour)
+	t.Cleanup(cancel)
 
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "mr",
-				Value: "!1 (foo) by @profclems",
-			},
-		})
+	ios := iostreams.New(iostreams.WithStdin(stdin, true), iostreams.WithStdout(stdout, true))
 
-		got, err := GetMRForBranch(&gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
-		assert.NoError(t, err)
+	got, err := GetMRForBranch(ios, &gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
+	assert.NoError(t, err)
 
-		assert.Equal(t, 1, got.IID)
-		assert.Equal(t, "profclems", got.Author.Username)
-	})
-
-	t.Run("error", func(t *testing.T) {
-		as, restoreAsk := prompt.InitAskStubber()
-		defer restoreAsk()
-
-		as.Stub([]*prompt.QuestionStub{
-			{
-				Name:  "mr",
-				Value: errors.New("prompt failed"),
-			},
-		})
-
-		got, err := GetMRForBranch(&gitlab.Client{}, MrOptions{baseRepo, "foo", "opened", true})
-		assert.Nil(t, got)
-		assert.EqualError(t, err, "you must select a merge request: prompt failed")
-	})
+	assert.Equal(t, 1, got.IID)
+	assert.Equal(t, "profclems", got.Author.Username)
 }
 
 func Test_MRFromArgsWithOpts(t *testing.T) {
@@ -567,7 +548,7 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 			assert.Equal(t, "main", gotMR.SourceBranch)
 		})
 		t.Run("via-name", func(t *testing.T) {
-			GetMRForBranch = func(apiClient *gitlab.Client, mrOpts MrOptions) (*gitlab.BasicMergeRequest, error) {
+			GetMRForBranch = func(_ *iostreams.IOStreams, apiClient *gitlab.Client, mrOpts MrOptions) (*gitlab.BasicMergeRequest, error) {
 				return &gitlab.BasicMergeRequest{
 					IID:          2,
 					Title:        "test mr",
@@ -599,6 +580,125 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 			assert.Equal(t, "test mr", gotMR.Title)
 			assert.Equal(t, "main", gotMR.SourceBranch)
 		})
+		t.Run("via-URL", func(t *testing.T) {
+			api.GetMR = func(client *gitlab.Client, projectID any, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
+				// Verify the correct MR ID from the URL is being used
+				assert.Equal(t, 1234, mrID)
+				return &gitlab.MergeRequest{
+					BasicMergeRequest: gitlab.BasicMergeRequest{
+						IID:          1234,
+						Title:        "test mr from URL",
+						SourceBranch: "feature-branch",
+					},
+				}, nil
+			}
+
+			gotMR, gotRepo, err := MRFromArgs(baseFactory, []string{"https://gitlab.com/gitlab-org/cli/-/merge_requests/1234"}, "")
+			assert.NoError(t, err)
+
+			// The repository should be extracted from the URL
+			assert.Equal(t, "gitlab-org/cli", gotRepo.FullName())
+
+			assert.Equal(t, 1234, gotMR.IID)
+			assert.Equal(t, "test mr from URL", gotMR.Title)
+			assert.Equal(t, "feature-branch", gotMR.SourceBranch)
+		})
+		t.Run("via-URL-self-managed", func(t *testing.T) {
+			api.GetMR = func(client *gitlab.Client, projectID any, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
+				// Verify the correct MR ID from the URL is being used
+				assert.Equal(t, 42, mrID)
+				return &gitlab.MergeRequest{
+					BasicMergeRequest: gitlab.BasicMergeRequest{
+						IID:          42,
+						Title:        "test mr from self-managed",
+						SourceBranch: "feature-branch",
+					},
+				}, nil
+			}
+
+			// Need to create a factory that can handle different hosts
+			f := cmdtest.NewTestFactory(ios,
+				cmdtest.WithBaseRepo("kde", "krita", "invent.kde.org"),
+				cmdtest.WithBranch("main"),
+			)
+
+			gotMR, gotRepo, err := MRFromArgs(f, []string{"https://invent.kde.org/kde/krita/-/merge_requests/42"}, "")
+			assert.NoError(t, err)
+
+			// The repository should be extracted from the URL
+			assert.Equal(t, "kde/krita", gotRepo.FullName())
+			assert.Equal(t, "invent.kde.org", gotRepo.RepoHost())
+
+			assert.Equal(t, 42, gotMR.IID)
+			assert.Equal(t, "test mr from self-managed", gotMR.Title)
+			assert.Equal(t, "feature-branch", gotMR.SourceBranch)
+		})
+		t.Run("via-URL-cross-instance", func(t *testing.T) {
+			api.GetMR = func(client *gitlab.Client, projectID any, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
+				// Verify the correct MR ID from the URL is being used
+				assert.Equal(t, 42, mrID)
+				return &gitlab.MergeRequest{
+					BasicMergeRequest: gitlab.BasicMergeRequest{
+						IID:          42,
+						Title:        "test mr from cross instance",
+						SourceBranch: "feature-branch",
+					},
+				}, nil
+			}
+
+			// Create a factory with gitlab.com as base, but test with invent.kde.org URL
+			// This tests the cross-instance hostname comparison logic
+			f := cmdtest.NewTestFactory(ios,
+				cmdtest.WithBaseRepo("gitlab-org", "cli", "gitlab.com"),
+				cmdtest.WithBranch("main"),
+			)
+
+			gotMR, gotRepo, err := MRFromArgs(f, []string{"https://invent.kde.org/kde/krita/-/merge_requests/42"}, "")
+			assert.NoError(t, err)
+
+			// The repository should be extracted from the URL (different from base repo)
+			assert.Equal(t, "kde/krita", gotRepo.FullName())
+			assert.Equal(t, "invent.kde.org", gotRepo.RepoHost())
+
+			assert.Equal(t, 42, gotMR.IID)
+			assert.Equal(t, "test mr from cross instance", gotMR.Title)
+			assert.Equal(t, "feature-branch", gotMR.SourceBranch)
+		})
+		t.Run("via-URL-cross-instance-api-client", func(t *testing.T) {
+			api.GetMR = func(client *gitlab.Client, projectID any, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
+				return &gitlab.MergeRequest{
+					BasicMergeRequest: gitlab.BasicMergeRequest{
+						IID:          42,
+						Title:        "test mr api client",
+						SourceBranch: "feature-branch",
+					},
+				}, nil
+			}
+
+			// Track which hostname was used for ApiClient call
+			var capturedHostname string
+
+			f := cmdtest.NewTestFactory(ios,
+				cmdtest.WithBaseRepo("gitlab-org", "cli", "gitlab.com"),
+				cmdtest.WithBranch("main"),
+			)
+
+			// Override ApiClient to capture the hostname parameter
+			originalApiClient := f.ApiClientStub
+			f.ApiClientStub = func(repoHost string) (*api.Client, error) {
+				capturedHostname = repoHost
+				return originalApiClient(repoHost) // Call original implementation
+			}
+
+			gotMR, gotRepo, err := MRFromArgs(f, []string{"https://custom.gitlab.com/user/repo/-/merge_requests/42"}, "")
+			assert.NoError(t, err)
+
+			// Verify that ApiClient was called with the correct hostname from URL
+			assert.Equal(t, "custom.gitlab.com", capturedHostname)
+			assert.Equal(t, "user/repo", gotRepo.FullName())
+			assert.Equal(t, "custom.gitlab.com", gotRepo.RepoHost())
+			assert.Equal(t, 42, gotMR.IID)
+		})
 	})
 
 	t.Run("fail", func(t *testing.T) {
@@ -643,7 +743,7 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 			assert.EqualError(t, err, "invalid merge request ID provided.")
 		})
 		t.Run("invalid-name", func(t *testing.T) {
-			GetMRForBranch = func(_ *gitlab.Client, mrOpts MrOptions) (*gitlab.BasicMergeRequest, error) {
+			GetMRForBranch = func(_ *iostreams.IOStreams, _ *gitlab.Client, mrOpts MrOptions) (*gitlab.BasicMergeRequest, error) {
 				return nil, fmt.Errorf("no merge requests from branch %q", mrOpts.Branch)
 			}
 
@@ -662,6 +762,29 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 			assert.Nil(t, gotRepo)
 			assert.EqualError(t, err, "failed to get merge request 2: API call failed")
 		})
+		t.Run("URL-with-API-failure", func(t *testing.T) {
+			api.GetMR = func(client *gitlab.Client, projectID any, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
+				// This should be called with the ID from the URL (1234)
+				assert.Equal(t, 1234, mrID)
+				return nil, errors.New("API call failed for URL MR")
+			}
+
+			gotMR, gotRepo, err := MRFromArgs(baseFactory, []string{"https://gitlab.com/gitlab-org/cli/-/merge_requests/1234"}, "")
+			assert.Nil(t, gotMR)
+			assert.Nil(t, gotRepo)
+			assert.EqualError(t, err, "failed to get merge request 1234: API call failed for URL MR")
+		})
+		t.Run("URL-without-scheme", func(t *testing.T) {
+			// Test that a URL without a scheme (http/https) fails to parse and falls back to branch lookup
+			GetMRForBranch = func(_ *iostreams.IOStreams, _ *gitlab.Client, mrOpts MrOptions) (*gitlab.BasicMergeRequest, error) {
+				return nil, fmt.Errorf("no merge requests from branch %q", mrOpts.Branch)
+			}
+
+			gotMR, gotRepo, err := MRFromArgs(baseFactory, []string{"gitlab.com/gitlab-org/cli/-/merge_requests/1234"}, "")
+			assert.Nil(t, gotMR)
+			assert.Nil(t, gotRepo)
+			assert.EqualError(t, err, `no merge requests from branch "gitlab.com/gitlab-org/cli/-/merge_requests/1234"`)
+		})
 	})
 }
 
